According to Olivoto et al. (2019a), WAASB(The weighted average of
absolute scores) is computed considering all Interaction Principal
Component Axis (IPCA) from the Singular Value Decomposition (SVD)
of the matrix of genotype-environment interaction (GEI) effects
generated by a linear mixed-effect model, as follows:
WAASB_i = _k = 1^p |IPCA_ik EP_k|/
_k = 1^pEP_k
where WAASB_i is the weighted average of absolute scores
of the ith genotype; IPCA_ik is the score of the ith
genotype in the kth Interaction Principal Component Axis (IPCA);
and EP_k is the explained variance of the kth IPCA for
k = 1,2,..,p, considering p=min(g-1; e-1).
Further, WAASBY_i is a superiority or simultaneous
selection index allowing weighting between mean performance
and stability
WAASBY_i=(rY_i_Y)+
(rW_i_s)_Y+_s
, where WAASBY_i is the superiority index for genotype
i that weights between mean performance and stability;
_Y and _s are the weights for
mean performance and stability, respectively; rY_i and
rW_i are the rescaled values for mean performance
Y_i and stability W_i, respectively of
the genotype i. For the details of calculations, rescaling
and mathematics notations see (Olivoto et al., 2019).
Finally, rYWAASB_i index is the sum of the ranks
(or in fact the rank of sum of ranks of the trait and
WAASB index) as follows:
(rY_i) and WAASB index (rWAASB_i) for each
individual:
rYWAASB_i = rY_i + rWAASB_i or: =
rankrY_i + rWAASB_i.
The input format of table of data(NA free), here maize data,
should be as follows:
| GEN | Y | WAASB | WAASBY |
| Dracma | 262.22 | 0.81 | 81.6 |
| DKC6630 | 284.04 | 2.20 | 88.5 |
| NS770 | 243.48 | 0.33 | 71.4 |