# Case 1: Higher trait values are preferred. For instance grain yield
# in cereals is a trait which its higher values are preferred and ranking
# is performed from the higher to lower values i.e. 1st, 2nd, 3rd etc
# in maize dataset.
# \donttest{
data(maize)
bar_plot2(maize) # or: bar_plot2(maize, lowt = FALSE, verbose = FALSE)
# }
# Case 2: In this case, the lower values of the given trait are preferred.
# For instance days to maturity (dm) and plant height are traits where their
# lower values are preferred.
# \donttest{
data(dm)
bar_plot2(dm, lowt = TRUE, verbose = TRUE)
# }
Run the code above in your browser using DataLab